#!/bin/sh
#  Author: Paulo Roma 10/10/2008
#
#  Start arp-based proxying to a tuntap network device,
#  by using parprouted.
# 
#  Required for VirtualBox guests that use 
#  HIN (Host Interface Networking) over a wireless network.
#  The oft-touted bridging route works over host's 
#  wired ethernet, but will not work if the host uses a wireless nic.
#  This way, Virtualbox can have its own IP, and be seen in
#  a windows network, for instance.
#
#  Requires iproute and tunctl.
#
#  $1 is the network interface to be used.
#  $2 is the address/mask to be used.
#  $3 is the user owning the created TAP interface.
#
#  Example: parprouted-up.sh wlan0 192.168.254.5/24 john
#

if [ -z "$2" ]; then
   echo "Usage: parprouted-up.sh interface address/mask username"
   exit 0;
fi

TAP=tap0
ETH="$1"
ADDR="$2"
USER="$3"

#/sbin/sysctl net.ipv4.ip_forward=1
#/usr/bin/VBoxTunctl -b -u $USER
/usr/sbin/tunctl -t $TAP -u $USER
/sbin/ip link set $TAP up

echo "interface:" $ETH
echo "address:  " $ADDR
echo "user:     " $USER

/sbin/ip addr add $ADDR dev $TAP
/usr/bin/parprouted $ETH $TAP

